changefinder
===========

Online Change-Point Detection Library based on ChangeFinder Algorithm.

Authors & Contributors
----------------------

* Shunsuke Aihara - http://argmax.jp

License
=======

This code is licensed under MIT License.
